@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -141,6 +141,29 @@ class IoaClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAggrSoftCategorySoftList(self, request):
+        """聚合的分类软件列表
+
+        :param request: Request instance for DescribeAggrSoftCategorySoftList.
+        :type request: :class:`tencentcloud.ioa.v20220601.models.DescribeAggrSoftCategorySoftListRequest`
+        :rtype: :class:`tencentcloud.ioa.v20220601.models.DescribeAggrSoftCategorySoftListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAggrSoftCategorySoftList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAggrSoftCategorySoftListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDLPFileDetectResult(self, request):
         """webservice查询文件检测结果
 
@@ -164,6 +187,29 @@ class IoaClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDeviceChildGroups(self, request):
+        """查询设备组子分组详情，私有化调用path为：capi/Assets/Device/DescribeDeviceChildGroups
+
+        :param request: Request instance for DescribeDeviceChildGroups.
+        :type request: :class:`tencentcloud.ioa.v20220601.models.DescribeDeviceChildGroupsRequest`
+        :rtype: :class:`tencentcloud.ioa.v20220601.models.DescribeDeviceChildGroupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDeviceChildGroups", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDeviceChildGroupsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDeviceHardwareInfoList(self, request):
         """查询满足条件的查询终端硬件信息列表，私有化调用path为：/capi/Assets/Device/DescribeDeviceHardwareInfoList
 
@@ -210,6 +256,29 @@ class IoaClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDeviceVirtualGroups(self, request):
+        """查询终端自定义分组列表，私有化调用path为：/capi/Assets/Device/DescribeDeviceVirtualGroups
+
+        :param request: Request instance for DescribeDeviceVirtualGroups.
+        :type request: :class:`tencentcloud.ioa.v20220601.models.DescribeDeviceVirtualGroupsRequest`
+        :rtype: :class:`tencentcloud.ioa.v20220601.models.DescribeDeviceVirtualGroupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDeviceVirtualGroups", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDeviceVirtualGroupsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDevices(self, request):
         """查询满足条件的终端数据详情，私有化调用path为：/capi/Assets/Device/DescribeDevices
 
@@ -318,6 +387,52 @@ class IoaClient(AbstractClient):
             model = models.DescribeSoftwareInformationResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeVirtualDevices(self, request):
+        """展示自定义分组终端列表，私有化调用path为：/capi/Assets/DescribeVirtualDevices
+
+        :param request: Request instance for DescribeVirtualDevices.
+        :type request: :class:`tencentcloud.ioa.v20220601.models.DescribeVirtualDevicesRequest`
+        :rtype: :class:`tencentcloud.ioa.v20220601.models.DescribeVirtualDevicesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeVirtualDevices", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeVirtualDevicesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyVirtualDeviceGroups(self, request):
+        """终端自定义分组增减终端，私有化调用path为：/capi/Assets/Device/ModifyVirtualDeviceGroups
+
+        :param request: Request instance for ModifyVirtualDeviceGroups.
+        :type request: :class:`tencentcloud.ioa.v20220601.models.ModifyVirtualDeviceGroupsRequest`
+        :rtype: :class:`tencentcloud.ioa.v20220601.models.ModifyVirtualDeviceGroupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyVirtualDeviceGroups", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyVirtualDeviceGroupsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
